translate.tools.pogrep.GrepMatch

Package translate :: Package tools :: Module pogrep :: Class GrepMatch |
[hide private]
[frames] | no frames]

# Class GrepMatch

source code

Just a small data structure that represents a search match.

Instance Methods | [hide private]
__init__(self, unit, part=`'``target``'`, part_n=0, start=0, end=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
get_getter(self) | source code
get_setter(self) | source code
__str__(self) str(x) | source code
__repr__(self) repr(x) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, unit, part=`'``target``'`, part_n=0, start=0, end=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)